/****************************************************************************
** Meta object code from reading C++ file 'breezestackedwidgetdata.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/breeze-5.8.8/kstyle/animations/breezestackedwidgetdata.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'breezestackedwidgetdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Breeze__StackedWidgetData[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      32,   26,   27,   26, 0x09,
      54,   26,   27,   26, 0x09,
      64,   26,   26,   26, 0x09,
      82,   26,   26,   26, 0x09,

       0        // eod
};

static const char qt_meta_stringdata_Breeze__StackedWidgetData[] = {
    "Breeze::StackedWidgetData\0\0bool\0"
    "initializeAnimation()\0animate()\0"
    "finishAnimation()\0targetDestroyed()\0"
};

void Breeze::StackedWidgetData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        StackedWidgetData *_t = static_cast<StackedWidgetData *>(_o);
        switch (_id) {
        case 0: { bool _r = _t->initializeAnimation();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 1: { bool _r = _t->animate();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 2: _t->finishAnimation(); break;
        case 3: _t->targetDestroyed(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Breeze::StackedWidgetData::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Breeze::StackedWidgetData::staticMetaObject = {
    { &TransitionData::staticMetaObject, qt_meta_stringdata_Breeze__StackedWidgetData,
      qt_meta_data_Breeze__StackedWidgetData, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Breeze::StackedWidgetData::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Breeze::StackedWidgetData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Breeze::StackedWidgetData::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Breeze__StackedWidgetData))
        return static_cast<void*>(const_cast< StackedWidgetData*>(this));
    return TransitionData::qt_metacast(_clname);
}

int Breeze::StackedWidgetData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TransitionData::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
