/****************************************************************************
** Meta object code from reading C++ file 'breezebusyindicatorengine.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/breeze-5.8.8/kstyle/animations/breezebusyindicatorengine.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'breezebusyindicatorengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Breeze__BusyIndicatorEngine[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       1,   19, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      34,   28,   29,   28, 0x0a,

 // properties: name, type, flags
      65,   61, 0x02095103,

       0        // eod
};

static const char qt_meta_stringdata_Breeze__BusyIndicatorEngine[] = {
    "Breeze::BusyIndicatorEngine\0\0bool\0"
    "unregisterWidget(QObject*)\0int\0value\0"
};

void Breeze::BusyIndicatorEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        BusyIndicatorEngine *_t = static_cast<BusyIndicatorEngine *>(_o);
        switch (_id) {
        case 0: { bool _r = _t->unregisterWidget((*reinterpret_cast< QObject*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Breeze::BusyIndicatorEngine::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Breeze::BusyIndicatorEngine::staticMetaObject = {
    { &BaseEngine::staticMetaObject, qt_meta_stringdata_Breeze__BusyIndicatorEngine,
      qt_meta_data_Breeze__BusyIndicatorEngine, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Breeze::BusyIndicatorEngine::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Breeze::BusyIndicatorEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Breeze::BusyIndicatorEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Breeze__BusyIndicatorEngine))
        return static_cast<void*>(const_cast< BusyIndicatorEngine*>(this));
    return BaseEngine::qt_metacast(_clname);
}

int Breeze::BusyIndicatorEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseEngine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
      else if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = value(); break;
        }
        _id -= 1;
    } else if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: setValue(*reinterpret_cast< int*>(_v)); break;
        }
        _id -= 1;
    } else if (_c == QMetaObject::ResetProperty) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_END_MOC_NAMESPACE
