#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'breezeconfigurationui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BREEZECONFIGURATIONUI_H
#define UI_BREEZECONFIGURATIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "config/breezeexceptionlistwidget.h"
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_BreezeConfigurationUI
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_4;
    QLabel *label_3;
    QLabel *label_4;
    QComboBox *buttonSize;
    QComboBox *titleAlignment;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QCheckBox *drawSizeGrip;
    QCheckBox *drawBorderOnMaximizedWindows;
    QCheckBox *outlineCloseButton;
    QCheckBox *drawBackgroundGradient;
    QWidget *tab_2;
    QGridLayout *gridLayout_5;
    QLabel *animationsDurationLabel;
    QSpinBox *animationsDuration;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *animationsEnabled;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_4;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *shadowSize;
    QLabel *label_2;
    QSpinBox *shadowStrength;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_5;
    KColorButton *shadowColor;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_3;
    Breeze::ExceptionListWidget *exceptions;

    void setupUi(QWidget *BreezeConfigurationUI)
    {
        if (BreezeConfigurationUI->objectName().isEmpty())
            BreezeConfigurationUI->setObjectName(QStringLiteral("BreezeConfigurationUI"));
        BreezeConfigurationUI->resize(428, 418);
        verticalLayout = new QVBoxLayout(BreezeConfigurationUI);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(BreezeConfigurationUI);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout_4 = new QGridLayout(tab);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        label_3 = new QLabel(tab);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(tab);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_4, 1, 0, 1, 1);

        buttonSize = new QComboBox(tab);
        buttonSize->setObjectName(QStringLiteral("buttonSize"));

        gridLayout_4->addWidget(buttonSize, 1, 1, 1, 1);

        titleAlignment = new QComboBox(tab);
        titleAlignment->setObjectName(QStringLiteral("titleAlignment"));

        gridLayout_4->addWidget(titleAlignment, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 6, 0, 1, 3);

        drawSizeGrip = new QCheckBox(tab);
        drawSizeGrip->setObjectName(QStringLiteral("drawSizeGrip"));

        gridLayout_4->addWidget(drawSizeGrip, 5, 0, 1, 3);

        drawBorderOnMaximizedWindows = new QCheckBox(tab);
        drawBorderOnMaximizedWindows->setObjectName(QStringLiteral("drawBorderOnMaximizedWindows"));

        gridLayout_4->addWidget(drawBorderOnMaximizedWindows, 3, 0, 1, 3);

        outlineCloseButton = new QCheckBox(tab);
        outlineCloseButton->setObjectName(QStringLiteral("outlineCloseButton"));

        gridLayout_4->addWidget(outlineCloseButton, 2, 0, 1, 3);

        drawBackgroundGradient = new QCheckBox(tab);
        drawBackgroundGradient->setObjectName(QStringLiteral("drawBackgroundGradient"));

        gridLayout_4->addWidget(drawBackgroundGradient, 4, 0, 1, 3);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout_5 = new QGridLayout(tab_2);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        animationsDurationLabel = new QLabel(tab_2);
        animationsDurationLabel->setObjectName(QStringLiteral("animationsDurationLabel"));
        animationsDurationLabel->setEnabled(false);
        animationsDurationLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(animationsDurationLabel, 1, 0, 1, 1);

        animationsDuration = new QSpinBox(tab_2);
        animationsDuration->setObjectName(QStringLiteral("animationsDuration"));
        animationsDuration->setEnabled(false);
        animationsDuration->setMaximum(500);

        gridLayout_5->addWidget(animationsDuration, 1, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_4, 1, 2, 1, 1);

        animationsEnabled = new QCheckBox(tab_2);
        animationsEnabled->setObjectName(QStringLiteral("animationsEnabled"));

        gridLayout_5->addWidget(animationsEnabled, 0, 0, 1, 3);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_5->addItem(verticalSpacer_2, 2, 0, 1, 3);

        tabWidget->addTab(tab_2, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QStringLiteral("tab_4"));
        gridLayout = new QGridLayout(tab_4);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(tab_4);
        label->setObjectName(QStringLiteral("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        shadowSize = new QSpinBox(tab_4);
        shadowSize->setObjectName(QStringLiteral("shadowSize"));
        shadowSize->setMinimum(6);
        shadowSize->setMaximum(64);

        gridLayout->addWidget(shadowSize, 0, 1, 1, 1);

        label_2 = new QLabel(tab_4);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        shadowStrength = new QSpinBox(tab_4);
        shadowStrength->setObjectName(QStringLiteral("shadowStrength"));
        shadowStrength->setMinimum(10);
        shadowStrength->setMaximum(100);

        gridLayout->addWidget(shadowStrength, 1, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 1, 2, 1, 1);

        label_5 = new QLabel(tab_4);
        label_5->setObjectName(QStringLiteral("label_5"));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        shadowColor = new KColorButton(tab_4);
        shadowColor->setObjectName(QStringLiteral("shadowColor"));

        gridLayout->addWidget(shadowColor, 2, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 3);

        tabWidget->addTab(tab_4, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        verticalLayout_3 = new QVBoxLayout(tab_3);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        exceptions = new Breeze::ExceptionListWidget(tab_3);
        exceptions->setObjectName(QStringLiteral("exceptions"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(exceptions->sizePolicy().hasHeightForWidth());
        exceptions->setSizePolicy(sizePolicy);

        verticalLayout_3->addWidget(exceptions);

        tabWidget->addTab(tab_3, QString());

        verticalLayout->addWidget(tabWidget);

#ifndef UI_QT_NO_SHORTCUT
        label_3->setBuddy(titleAlignment);
        label_4->setBuddy(buttonSize);
        animationsDurationLabel->setBuddy(animationsDuration);
        label->setBuddy(shadowSize);
        label_2->setBuddy(shadowStrength);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(tabWidget, titleAlignment);
        QWidget::setTabOrder(titleAlignment, buttonSize);
        QWidget::setTabOrder(buttonSize, outlineCloseButton);
        QWidget::setTabOrder(outlineCloseButton, drawBorderOnMaximizedWindows);
        QWidget::setTabOrder(drawBorderOnMaximizedWindows, drawBackgroundGradient);
        QWidget::setTabOrder(drawBackgroundGradient, drawSizeGrip);
        QWidget::setTabOrder(drawSizeGrip, animationsEnabled);
        QWidget::setTabOrder(animationsEnabled, animationsDuration);
        QWidget::setTabOrder(animationsDuration, shadowSize);
        QWidget::setTabOrder(shadowSize, shadowStrength);
        QWidget::setTabOrder(shadowStrength, shadowColor);

        retranslateUi(BreezeConfigurationUI);
        QObject::connect(animationsEnabled, SIGNAL(toggled(bool)), animationsDurationLabel, SLOT(setEnabled(bool)));
        QObject::connect(animationsEnabled, SIGNAL(toggled(bool)), animationsDuration, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BreezeConfigurationUI);
    } // setupUi

    void retranslateUi(QWidget *BreezeConfigurationUI)
    {
        label_3->setText(tr2i18n("Tit&le alignment:", Q_NULLPTR));
        label_4->setText(tr2i18n("B&utton size:", Q_NULLPTR));
        buttonSize->clear();
        buttonSize->insertItems(0, QStringList()
         << tr2i18n("Tiny", Q_NULLPTR)
         << tr2i18n("Small", "@item:inlistbox Button size:")
         << tr2i18n("Normal", "@item:inlistbox Button size:")
         << tr2i18n("Large", "@item:inlistbox Button size:")
         << tr2i18n("Very Large", "@item:inlistbox Button size:")
        );
        titleAlignment->clear();
        titleAlignment->insertItems(0, QStringList()
         << tr2i18n("Left", Q_NULLPTR)
         << tr2i18n("Center", Q_NULLPTR)
         << tr2i18n("Center (Full Width)", Q_NULLPTR)
         << tr2i18n("Right", Q_NULLPTR)
        );
        drawSizeGrip->setText(tr2i18n("Add handle to resize windows with no border", Q_NULLPTR));
        drawBorderOnMaximizedWindows->setText(tr2i18n("Display window borders for maximized windows", Q_NULLPTR));
        outlineCloseButton->setText(tr2i18n("Draw a circle around close button", Q_NULLPTR));
        drawBackgroundGradient->setText(tr2i18n("Draw window background gradient", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("General", Q_NULLPTR));
        animationsDurationLabel->setText(tr2i18n("Anima&tions duration:", Q_NULLPTR));
        animationsDuration->setSuffix(tr2i18n("ms", Q_NULLPTR));
        animationsEnabled->setText(tr2i18n("Enable animations", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Animations", Q_NULLPTR));
        label->setText(tr2i18n("Si&ze:", Q_NULLPTR));
        shadowSize->setSuffix(tr2i18n("px", Q_NULLPTR));
        label_2->setText(tr2i18n("S&trength:", "strength of the shadow (from transparent to opaque)"));
        shadowStrength->setSuffix(tr2i18n("%", Q_NULLPTR));
        label_5->setText(tr2i18n("Color:", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Shadows", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Window-Specific Overrides", Q_NULLPTR));
        Q_UNUSED(BreezeConfigurationUI);
    } // retranslateUi

};

namespace Ui {
    class BreezeConfigurationUI: public Ui_BreezeConfigurationUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BREEZECONFIGURATIONUI_H

