#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'breezestyleconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BREEZESTYLECONFIG_H
#define UI_BREEZESTYLECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BreezeStyleConfig
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout;
    QLabel *_windowDragLabel;
    QCheckBox *_viewDrawFocusIndicator;
    QLabel *_mnemonicsLabel;
    QComboBox *_mnemonicsMode;
    QSpacerItem *horizontalSpacer_3;
    QComboBox *_windowDragMode;
    QSpacerItem *verticalSpacer;
    QCheckBox *_tabBarDrawCenteredTabs;
    QCheckBox *_toolBarDrawItemSeparator;
    QCheckBox *_sliderDrawTickMarks;
    QCheckBox *_splitterProxyEnabled;
    QWidget *tab_2;
    QGridLayout *gridLayout_5;
    QLabel *_animationsDurationLabel;
    QSpinBox *_animationsDuration;
    QCheckBox *_animationsEnabled;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *_dockWidgetDrawFrame;
    QCheckBox *_titleWidgetDrawFrame;
    QCheckBox *_sidePanelDrawFrame;
    QCheckBox *_menuItemDrawThinFocus;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_4;
    QGridLayout *gridLayout_6;
    QLabel *_scrollBarAddLineLabel;
    QLabel *_scrollBarSubLineLabel;
    QComboBox *_scrollBarSubLineButtons;
    QComboBox *_scrollBarAddLineButtons;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *BreezeStyleConfig)
    {
        if (BreezeStyleConfig->objectName().isEmpty())
            BreezeStyleConfig->setObjectName(QStringLiteral("BreezeStyleConfig"));
        BreezeStyleConfig->resize(464, 246);
        verticalLayout_2 = new QVBoxLayout(BreezeStyleConfig);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        tabWidget = new QTabWidget(BreezeStyleConfig);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        gridLayout = new QGridLayout(tab);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        _windowDragLabel = new QLabel(tab);
        _windowDragLabel->setObjectName(QStringLiteral("_windowDragLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_windowDragLabel->sizePolicy().hasHeightForWidth());
        _windowDragLabel->setSizePolicy(sizePolicy);
        _windowDragLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(_windowDragLabel, 6, 1, 1, 1);

        _viewDrawFocusIndicator = new QCheckBox(tab);
        _viewDrawFocusIndicator->setObjectName(QStringLiteral("_viewDrawFocusIndicator"));

        gridLayout->addWidget(_viewDrawFocusIndicator, 2, 1, 1, 4);

        _mnemonicsLabel = new QLabel(tab);
        _mnemonicsLabel->setObjectName(QStringLiteral("_mnemonicsLabel"));
        _mnemonicsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(_mnemonicsLabel, 5, 1, 1, 1);

        _mnemonicsMode = new QComboBox(tab);
        _mnemonicsMode->setObjectName(QStringLiteral("_mnemonicsMode"));

        gridLayout->addWidget(_mnemonicsMode, 5, 2, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(65, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 5, 4, 1, 1);

        _windowDragMode = new QComboBox(tab);
        _windowDragMode->setObjectName(QStringLiteral("_windowDragMode"));

        gridLayout->addWidget(_windowDragMode, 6, 2, 1, 2);

        verticalSpacer = new QSpacerItem(20, 49, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 1, 1, 3);

        _tabBarDrawCenteredTabs = new QCheckBox(tab);
        _tabBarDrawCenteredTabs->setObjectName(QStringLiteral("_tabBarDrawCenteredTabs"));

        gridLayout->addWidget(_tabBarDrawCenteredTabs, 0, 1, 1, 4);

        _toolBarDrawItemSeparator = new QCheckBox(tab);
        _toolBarDrawItemSeparator->setObjectName(QStringLiteral("_toolBarDrawItemSeparator"));

        gridLayout->addWidget(_toolBarDrawItemSeparator, 1, 1, 1, 4);

        _sliderDrawTickMarks = new QCheckBox(tab);
        _sliderDrawTickMarks->setObjectName(QStringLiteral("_sliderDrawTickMarks"));

        gridLayout->addWidget(_sliderDrawTickMarks, 3, 1, 1, 4);

        _splitterProxyEnabled = new QCheckBox(tab);
        _splitterProxyEnabled->setObjectName(QStringLiteral("_splitterProxyEnabled"));

        gridLayout->addWidget(_splitterProxyEnabled, 4, 1, 1, 4);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QStringLiteral("tab_2"));
        gridLayout_5 = new QGridLayout(tab_2);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        _animationsDurationLabel = new QLabel(tab_2);
        _animationsDurationLabel->setObjectName(QStringLiteral("_animationsDurationLabel"));
        _animationsDurationLabel->setEnabled(false);
        _animationsDurationLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(_animationsDurationLabel, 1, 0, 1, 1);

        _animationsDuration = new QSpinBox(tab_2);
        _animationsDuration->setObjectName(QStringLiteral("_animationsDuration"));
        _animationsDuration->setEnabled(false);
        _animationsDuration->setMaximum(500);

        gridLayout_5->addWidget(_animationsDuration, 1, 1, 1, 2);

        _animationsEnabled = new QCheckBox(tab_2);
        _animationsEnabled->setObjectName(QStringLiteral("_animationsEnabled"));

        gridLayout_5->addWidget(_animationsEnabled, 0, 0, 1, 4);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_5->addItem(horizontalSpacer, 1, 3, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_5->addItem(verticalSpacer_2, 2, 0, 1, 4);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QStringLiteral("tab_3"));
        verticalLayout_3 = new QVBoxLayout(tab_3);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        _dockWidgetDrawFrame = new QCheckBox(tab_3);
        _dockWidgetDrawFrame->setObjectName(QStringLiteral("_dockWidgetDrawFrame"));

        verticalLayout_3->addWidget(_dockWidgetDrawFrame);

        _titleWidgetDrawFrame = new QCheckBox(tab_3);
        _titleWidgetDrawFrame->setObjectName(QStringLiteral("_titleWidgetDrawFrame"));

        verticalLayout_3->addWidget(_titleWidgetDrawFrame);

        _sidePanelDrawFrame = new QCheckBox(tab_3);
        _sidePanelDrawFrame->setObjectName(QStringLiteral("_sidePanelDrawFrame"));

        verticalLayout_3->addWidget(_sidePanelDrawFrame);

        _menuItemDrawThinFocus = new QCheckBox(tab_3);
        _menuItemDrawThinFocus->setObjectName(QStringLiteral("_menuItemDrawThinFocus"));

        verticalLayout_3->addWidget(_menuItemDrawThinFocus);

        verticalSpacer_3 = new QSpacerItem(20, 117, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QStringLiteral("tab_4"));
        gridLayout_6 = new QGridLayout(tab_4);
        gridLayout_6->setObjectName(QStringLiteral("gridLayout_6"));
        _scrollBarAddLineLabel = new QLabel(tab_4);
        _scrollBarAddLineLabel->setObjectName(QStringLiteral("_scrollBarAddLineLabel"));
        _scrollBarAddLineLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_6->addWidget(_scrollBarAddLineLabel, 1, 0, 1, 1);

        _scrollBarSubLineLabel = new QLabel(tab_4);
        _scrollBarSubLineLabel->setObjectName(QStringLiteral("_scrollBarSubLineLabel"));
        _scrollBarSubLineLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_6->addWidget(_scrollBarSubLineLabel, 0, 0, 1, 1);

        _scrollBarSubLineButtons = new QComboBox(tab_4);
        _scrollBarSubLineButtons->setObjectName(QStringLiteral("_scrollBarSubLineButtons"));

        gridLayout_6->addWidget(_scrollBarSubLineButtons, 0, 1, 1, 1);

        _scrollBarAddLineButtons = new QComboBox(tab_4);
        _scrollBarAddLineButtons->setObjectName(QStringLiteral("_scrollBarAddLineButtons"));

        gridLayout_6->addWidget(_scrollBarAddLineButtons, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_6->addItem(verticalSpacer_4, 2, 0, 1, 3);

        tabWidget->addTab(tab_4, QString());

        verticalLayout_2->addWidget(tabWidget);

#ifndef UI_QT_NO_SHORTCUT
        _windowDragLabel->setBuddy(_windowDragMode);
        _mnemonicsLabel->setBuddy(_mnemonicsMode);
        _animationsDurationLabel->setBuddy(_animationsDuration);
        _scrollBarAddLineLabel->setBuddy(_scrollBarAddLineButtons);
        _scrollBarSubLineLabel->setBuddy(_scrollBarSubLineButtons);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(tabWidget, _tabBarDrawCenteredTabs);
        QWidget::setTabOrder(_tabBarDrawCenteredTabs, _toolBarDrawItemSeparator);
        QWidget::setTabOrder(_toolBarDrawItemSeparator, _sliderDrawTickMarks);
        QWidget::setTabOrder(_sliderDrawTickMarks, _splitterProxyEnabled);
        QWidget::setTabOrder(_splitterProxyEnabled, _mnemonicsMode);
        QWidget::setTabOrder(_mnemonicsMode, _windowDragMode);
        QWidget::setTabOrder(_windowDragMode, _animationsEnabled);
        QWidget::setTabOrder(_animationsEnabled, _animationsDuration);
        QWidget::setTabOrder(_animationsDuration, _dockWidgetDrawFrame);
        QWidget::setTabOrder(_dockWidgetDrawFrame, _titleWidgetDrawFrame);
        QWidget::setTabOrder(_titleWidgetDrawFrame, _sidePanelDrawFrame);
        QWidget::setTabOrder(_sidePanelDrawFrame, _menuItemDrawThinFocus);
        QWidget::setTabOrder(_menuItemDrawThinFocus, _scrollBarSubLineButtons);
        QWidget::setTabOrder(_scrollBarSubLineButtons, _scrollBarAddLineButtons);

        retranslateUi(BreezeStyleConfig);
        QObject::connect(_animationsEnabled, SIGNAL(toggled(bool)), _animationsDurationLabel, SLOT(setEnabled(bool)));
        QObject::connect(_animationsEnabled, SIGNAL(toggled(bool)), _animationsDuration, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BreezeStyleConfig);
    } // setupUi

    void retranslateUi(QWidget *BreezeStyleConfig)
    {
        _windowDragLabel->setText(tr2i18n("W&indows' drag mode:", Q_NULLPTR));
        _viewDrawFocusIndicator->setText(tr2i18n("Draw focus indicator in lists", Q_NULLPTR));
        _mnemonicsLabel->setText(tr2i18n("&Keyboard accelerators visibility:", Q_NULLPTR));
        _mnemonicsMode->clear();
        _mnemonicsMode->insertItems(0, QStringList()
         << tr2i18n("Always Hide Keyboard Accelerators", Q_NULLPTR)
         << tr2i18n("Show Keyboard Accelerators When Needed", Q_NULLPTR)
         << tr2i18n("Always Show Keyboard Accelerators", Q_NULLPTR)
        );
        _windowDragMode->clear();
        _windowDragMode->insertItems(0, QStringList()
         << tr2i18n("Drag windows from titlebar only", Q_NULLPTR)
         << tr2i18n("Drag windows from titlebar, menubar and toolbars", Q_NULLPTR)
         << tr2i18n("Drag windows from all empty areas", Q_NULLPTR)
        );
        _tabBarDrawCenteredTabs->setText(tr2i18n("Center tabbar tabs", Q_NULLPTR));
        _toolBarDrawItemSeparator->setText(tr2i18n("Draw toolbar item separators", Q_NULLPTR));
        _sliderDrawTickMarks->setText(tr2i18n("Draw slider tick marks", Q_NULLPTR));
        _splitterProxyEnabled->setText(tr2i18n("Enable extended resize handles", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("General", Q_NULLPTR));
        _animationsDurationLabel->setText(tr2i18n("Animations d&uration:", Q_NULLPTR));
        _animationsDuration->setSuffix(tr2i18n("ms", Q_NULLPTR));
        _animationsEnabled->setText(tr2i18n("Enable animations", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Animations", Q_NULLPTR));
        _dockWidgetDrawFrame->setText(tr2i18n("Draw frame around dockable panels", Q_NULLPTR));
        _titleWidgetDrawFrame->setText(tr2i18n("Draw frame around page titles", Q_NULLPTR));
        _sidePanelDrawFrame->setText(tr2i18n("Draw frame around side panels", Q_NULLPTR));
        _menuItemDrawThinFocus->setText(tr2i18n("Draw a thin line to indicate focus in menus and menubars", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Frames", Q_NULLPTR));
        _scrollBarAddLineLabel->setText(tr2i18n("Botto&m arrow button type:", Q_NULLPTR));
        _scrollBarSubLineLabel->setText(tr2i18n("&Top arrow button type:", Q_NULLPTR));
        _scrollBarSubLineButtons->clear();
        _scrollBarSubLineButtons->insertItems(0, QStringList()
         << tr2i18n("No Buttons", Q_NULLPTR)
         << tr2i18n("One Button", Q_NULLPTR)
         << tr2i18n("Two Buttons", Q_NULLPTR)
        );
        _scrollBarAddLineButtons->clear();
        _scrollBarAddLineButtons->insertItems(0, QStringList()
         << tr2i18n("No Buttons", Q_NULLPTR)
         << tr2i18n("One Button", Q_NULLPTR)
         << tr2i18n("Two Buttons", Q_NULLPTR)
        );
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Scrollbars", Q_NULLPTR));
        Q_UNUSED(BreezeStyleConfig);
    } // retranslateUi

};

namespace Ui {
    class BreezeStyleConfig: public Ui_BreezeStyleConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BREEZESTYLECONFIG_H

